@@ -184,7 +184,6 @@ class ConnectionState:
         self.shard_count: Optional[int] = None
         self._ready_task: Optional[asyncio.Task] = None
         self.application_id: Optional[int] = utils._get_as_snowflake(options, 'application_id')
-        self.application_flags: ApplicationFlags = utils.MISSING
         self.heartbeat_timeout: float = options.get('heartbeat_timeout', 60.0)
         self.guild_ready_timeout: float = options.get('guild_ready_timeout', 2.0)
         if self.guild_ready_timeout < 0:
@@ -382,9 +381,6 @@ class ConnectionState:
         # the keys of self._guilds are ints
         return self._guilds.get(guild_id)  # type: ignore
 
-    def _get_or_create_unavailable_guild(self, guild_id: int) -> Guild:
-        return self._guilds.get(guild_id) or Guild._create_unavailable(state=self, guild_id=guild_id)
-
     def _add_guild(self, guild: Guild) -> None:
         self._guilds[guild.id] = guild
 
@@ -731,7 +727,7 @@ class ConnectionState:
             inner_data = data['data']
             custom_id = inner_data['custom_id']
             components = inner_data['components']
-            self._view_store.dispatch_modal(custom_id, interaction, components)
+            self._view_store.dispatch_modal(custom_id, interaction, components)  # type: ignore
         self.dispatch('interaction', interaction)
 
     def parse_presence_update(self, data: gw.PresenceUpdateEvent) -> None:
@@ -874,9 +870,8 @@ class ConnectionState:
             _log.debug('THREAD_UPDATE referencing an unknown guild ID: %s. Discarding', guild_id)
             return
 
-        raw = RawThreadUpdateEvent(data)
-        raw.thread = thread = guild.get_thread(raw.thread_id)
-        self.dispatch('raw_thread_update', raw)
+        thread_id = int(data['id'])
+        thread = guild.get_thread(thread_id)
         if thread is not None:
             old = copy.copy(thread)
             thread._update(data)
@@ -1487,7 +1482,7 @@ class ConnectionState:
         self.dispatch('raw_typing', raw)
 
     def _get_reaction_user(self, channel: MessageableChannel, user_id: int) -> Optional[Union[User, Member]]:
-        if isinstance(channel, (TextChannel, Thread, VoiceChannel)):
+        if isinstance(channel, TextChannel):
             return channel.guild.get_member(user_id)
         return self.get_user(user_id)
 
